cmd

package
v0.0.0-...-2a03479 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2017 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	AcceptTOSFlag          = "accept-tos"
	AcmeDirectoryFlag      = "acme-directory"
	ConfigFlag             = "config"
	EmailFlag              = "email"
	LetsEncryptStagingFlag = "le-staging"
	LogFlag                = "log"
	SealKeyFlag            = "seal-key"
)

Flag names

const (
	VulcandKey = "vulcand"
)

Flags

Variables

var (
	AcmeDirectoryProduction = "https://acme-v01.api.letsencrypt.org/directory"
	AcmeDirectoryStaging    = "https://acme-staging.api.letsencrypt.org/directory"
	LogDefault              = "info"
	StoreDefault            = "etcd"
	StoreNodesDefault       = []string{"127.0.0.1:2379"}
	StorePrefixDefault      = "coyote"
)

Default flag values

var RootCmd = &cobra.Command{
	Use:   "coyote",
	Short: "A utility to automate creation of TLS certificates using the ACME protocol",
}

RootCmd represents the base command when called without any subcommands

Functions

func Execute

func Execute()

Execute adds all child commands to the root command sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func NewCommandError

func NewCommandError(code int, err string) error

NewCommandError creates an error with a specified return code

func NewCommandErrorF

func NewCommandErrorF(code int, format string, a ...interface{}) error

NewCommandErrorF creates an error with a specified return code

func NewUserError

func NewUserError(err string) error

NewUserError creates a new user error

func NewUserErrorF

func NewUserErrorF(format string, a ...interface{}) error

NewUserErrorF creates a new user error with a formatted string

Types

type CommandError

type CommandError struct {
	// contains filtered or unexported fields
}

CommandError represents an error returned from a command

func (*CommandError) Code

func (e *CommandError) Code() int

Code gets the error code

func (*CommandError) Error

func (e *CommandError) Error() string

Error gets the error message

Jump to